==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/OrClassConstraintInList.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.query;

namespace com.db4o.test {

    public class OrClassConstraintInList {

        int cnt;
        IList list;
    
        public void configure(){
            Db4o.configure().objectClass(this).objectField("cnt").indexed(true);
        }
    
        public void store(){
            OrClassConstraintInList occ = new OrClassConstraintInList();
            occ.list = Tester.objectContainer().collections().newLinkedList();
            occ.list.Add(new Atom());
            Tester.store(occ);
            occ = new OrClassConstraintInList();
            occ.list = Tester.objectContainer().collections().newLinkedList();
            occ.cnt = 1;
            Tester.store(occ);
        }
    
        public void test(){
            Query q = Tester.query();
            q.constrain(typeof(OrClassConstraintInList));
            Constraint c1 = q.descend("list").constrain(typeof(Atom));
            Constraint c2 = q.descend("cnt").constrain(1);
            c1.or(c2);
            Tester.ensure(q.execute().size() == 2);
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/OrClassConstraintInList.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.query;

namespace com.db4o.test {

    public class OrClassConstraintInList {

        int cnt;
        IList list;
    
        public void Configure(){
            Db4o.Configure().ObjectClass(this).ObjectField("cnt").Indexed(true);
        }
    
        public void Store(){
            OrClassConstraintInList occ = new OrClassConstraintInList();
            occ.list = Tester.ObjectContainer().Collections().NewLinkedList();
            occ.list.Add(new Atom());
            Tester.Store(occ);
            occ = new OrClassConstraintInList();
            occ.list = Tester.ObjectContainer().Collections().NewLinkedList();
            occ.cnt = 1;
            Tester.Store(occ);
        }
    
        public void Test(){
            Query q = Tester.Query();
            q.Constrain(typeof(OrClassConstraintInList));
            Constraint c1 = q.Descend("list").Constrain(typeof(Atom));
            Constraint c2 = q.Descend("cnt").Constrain(1);
            c1.Or(c2);
            Tester.Ensure(q.Execute().Size() == 2);
        }
    }
}
